Method: AzureApplicationInsights::Channel::QueueBase#sender
- Defined in:
- lib/azure_application_insights/channel/queue_base.rb
#sender ⇒ SenderBase
The sender that is associated with this queue that this queue will use to send data to the service.
27 28 29 |
# File 'lib/azure_application_insights/channel/queue_base.rb', line 27 def sender @sender end |